@@ -20,6 +20,7 @@ from .core import (
     render,
     render_fixed,
     use_context,
+    use_effect,
     use_memo,
     use_reducer,
     use_ref,
@@ -41,6 +42,7 @@ __all__ = [
     "use_ref",
     "use_state",
     "use_state_widget",
+    "use_effect",
     "use_side_effect",
     "use_reducer",
     "provide_context",
