@@ -5,7 +5,7 @@ import ipyvue
 import react_ipywidgets as react
 
 
-def use_event(el: react.core.Element, event_and_modifiers, callback: Callable[[Any], None]):
+def use_event(el: react.core.Element, event_and_modifiers, callback: Callable[[Any], Any]):
     # to avoid add_event_handler having a stale reference to callback
     callback_ref = react.use_ref(callback)
     callback_ref.current = callback
@@ -23,4 +23,4 @@ def use_event(el: react.core.Element, event_and_modifiers, callback: Callable[[A
 
         return cleanup
 
-    react.use_side_effect(add_event_handler, [event_and_modifiers])
+    react.use_effect(add_event_handler, [event_and_modifiers])
